@@ -250,7 +250,9 @@ video_option_setup_list = [
     '96',       'hls [1080p] <96>',                         False,
     '139',      'm4a 48k (DASH Audio) <139>',               True,
     '140',      'm4a 128k (DASH Audio) <140>',              True,
+    '256',      'm4a 192k (DASH Audio) <256>',              True,
     '141',      'm4a 256k (DASH Audio) <141>',              True,
+    '258',      'm4a 384k (DASH Audio) <258>',              True,
     '18',       'mp4 [360p] <18>',                          False,
     '22',       'mp4 [720p] <22>',                          False,
     '37',       'mp4 [1080p] <37>',                         False,
@@ -279,6 +281,7 @@ video_option_setup_list = [
     '400',      'mp4 [1440p] <400>',                        False,
     '401',      'mp4 [2160p] <401>',                        False,
     '402',      'mp4 [2880p] <402>',                        False,
+    '571',      'mp4 [8k] <571',                            False,
     '43',       'webm [360p] <43>',                         False,
     '44',       'webm [480p] <44>',                         False,
     '45',       'webm [720p] <45>',                         False,
@@ -618,8 +621,10 @@ while language_setup_list:
     LANGUAGE_CODE_DICT[key] = value
 
 DIALOGUE_ICON_DICT = {
+    'newbie_classic_icon': 'newbie_classic_icon.png',
     'newbie_icon': 'newbie_icon_64.png',
     'ready_icon': 'ready_icon_64.png',
+    'setup_classic_icon': 'setup_classic_icon.png',
     'system_icon': 'system_icon_64.png',
     'yt_remind_icon_en': 'yt_remind_icon_en.png',
     'yt_remind_icon_kr': 'yt_remind_icon_kr.png',
@@ -757,6 +762,7 @@ SMALL_ICON_DICT = {
     'arrow_up_small': 'arrow_up.png',
     'arrow_down_small': 'arrow_down.png',
     'check_small': 'check.png',
+    'comment_small': 'comment.png',
     'debut_now_small': 'debut_now.png',
     'debut_wait_small': 'debut_wait.png',
     'delete_small': 'delete.png',
@@ -764,20 +770,23 @@ SMALL_ICON_DICT = {
     'download_small': 'download.png',
     'error_small': 'error.png',
     'external_small': 'external.png',
+    'favourite_small': 'favourite.png',
     'folder_black_small': 'folder_black.png',
     'folder_blue_small': 'folder_blue.png',
     'folder_green_small': 'folder_green.png',
     'folder_red_small': 'folder_red.png',
+    'likes_small': 'likes.png',
     'have_file_small': 'have_file.png',
     'live_now_small': 'live_now.png',
     'live_wait_small': 'live_wait.png',
     'no_file_small': 'no_file.png',
+    'slice_small': 'slice.png',
     'split_file_small': 'split_file.png',
-    'sponsorblock_small': 'sponsorblock.png',
+    'stamp_small': 'stamp.png',
     'system_error_small': 'system_error.png',
     'system_warning_small': 'system_warning.png',
-    'timestamp_small': 'timestamp.png',
     'unavailable_small': 'unavailable.png',
+    'uploader_small': 'uploader.png',
     'warning_small': 'warning.png',
 }
 
